@@ -28,15 +28,8 @@ class Message:
 
 class MessageRead:
     def __init__(self, data):
-        self.info = Message(data)
+        self.info: Message = Message(data)
         self.json = data
         self.content = data['textBody']
         self.htmlBody = data['htmlBody']
         self.attachments = data['attachments']
-
-'''
-body = r.json()['body']
-bod = BS(body, 'html.parser')
-bod = bod.find('a')
-bod = bod['href']
-'''
\ No newline at end of file
